function output = TFCExtractFeatures(cAudioList, windowSize )
%   File: TFCGetFeatures.m
%   Description: Process each audio file from cAudioList and gets its
%   musical features
%   Input:
%       cAudioList - Cell Array with audio files and labels
%       windowSize - Window size in seconds for framing
%   Output:
%       Cell Array with musical features of each entry of cAudioList        
%   Version: 1.0
%   Author: Juan Castro Mayorgas (jcastrom@uoc.edu)
%   (c) Copyright 2011 Juan Castro Mayorgas



    for index_i = 1:19
        cFeatures{index_i} = zeros(2,1);
    end
    cFeatures{20} = cell(2,1);
    cFeatures{21} = cell(2,1);
    cFeatures{22} = cell(2,1);


% check windowSize argument
if windowSize < 0.02 || windowSize > 0.10
    error ('el tamany de la finestra ha d''estar entre 0.02 i 0.10 s');
end

index = 1;

% Process every audio file
for m = 1:length(cAudioList{1})
    % split audio file into frames
    frames = mirframe(cAudioList{1}{m},'Length',windowSize,'s');
    % Calculate energy of every frame
    energy = mirrms(frames);
    % get reference to frame positions matrix
    pos = get(frames,'FramePos');
    % get reference to energy position matrix
    e = mirgetdata(energy);
    % process evry frame
    for n = 1:length(e)  
        % on get features if energy >= 0.06
        if (e(n) >= 0.06)
            % Get frame
            f = miraudio(cAudioList{1}{m},'Extract',pos{1}{1}(1,n),pos{1}{1}(2,n),'s');
            % save IDX
            cFeatures{1}(index)=m;
            % calculate Centroid
            out = mircentroid(f);
            cFeatures{2}(index)=mirgetdata(out);
            % calculate Spread
            out = mirspread(f);
            cFeatures{3}(index)=mirgetdata(out);
            % calculate MFCCs 1-13
            out = mirmfcc(f);
            mfcc = mirgetdata(out);
            cFeatures{4}(index)=mfcc(1);
            cFeatures{5}(index)=mfcc(2);
            cFeatures{6}(index)=mfcc(3);
            cFeatures{7}(index)=mfcc(4);
            cFeatures{8}(index)=mfcc(5);
            cFeatures{9}(index)=mfcc(6);
            cFeatures{10}(index)=mfcc(7);
            cFeatures{11}(index)=mfcc(8);
            cFeatures{12}(index)=mfcc(9);
            cFeatures{13}(index)=mfcc(10);
            cFeatures{14}(index)=mfcc(11);
            cFeatures{15}(index)=mfcc(12);
            cFeatures{16}(index)=mfcc(13);
            % calculate RollOff
            out = mirrolloff(f);
            cFeatures{17}(index)=mirgetdata(out);
            % calculate Zero-crossing
            out = mirzerocross(f);
            cFeatures{18}(index)=mirgetdata(out);            
            % calculate RMS
            cFeatures{19}(index)=e(n);   
            % save family
            cFeatures{20}{index}=cAudioList{2}{m};
            % save subfamily
            cFeatures{21}{index}=cAudioList{3}{m};
            % save instrument
            cFeatures{22}{index}=cAudioList{4}{m};
            index=index+1;
        end
    end
end
% returns features built cell array
output = cFeatures;
end

