function output = TFCGMMSearch ( cFeaturesTraining, mTraining, mTest, scale, classType )
%   File: TFCGMMSearch.m
%   Description: Perform GMM Classification
%   Input:
%       cFeaturesTraining - Cell Array with training features
%       mTraining - array with the features to check from training
%       mTest - array with features to classify from test
%       scale - 1 means to scale [-1,1]; 0 means not to scale
%       classType - Classes:
%                       0 - familia
%                       1 - subfamilia
%                       2 - instrument
%   Output:
%       Cell Array with Label classification and value of fdp
%
%   Version: 1.0
%   Author: Juan Castro Mayorgas (jcastrom@uoc.edu)
%   (c) Copyright 2011 Juan Castro Mayorgas

    % Check classtype
    if classType < 0 || classType > 2
        error ('Tipo de Class erroni');
    end
    
    % Scale if needed
    if scale == 1
        [mWorkTraining mWorkTest] = TFCScaleMatrices (mTraining, mTest);
    elseif scale == 0
        mWorkTraining  = mTraining;
        mWorkTest = mTest;
    else
        error ('error en el parametre ''scale''');
    end
    
    % create result cell array columns
    results{1} = cell(length(mWorkTest(:,1)),1);
    results{2} = zeros(length(mWorkTest(:,1)),1);
    
    Classes = {};
    LABELS = cFeaturesTraining{20 + classType};
    
    % find classes
    index_cell = 0;
    for index_i = 1:length(LABELS)
        index_j = 1;
        while index_j <= index_cell
            if strcmp(Classes{index_j},LABELS{index_i}) == 1
                break
            end
            index_j = index_j + 1;
        end
        if index_j > index_cell
            Classes{index_cell + 1} = LABELS{index_i};
            index_cell = index_cell + 1;
        end
    end
    
    num_classes = length(Classes);
    objGMM = {};
    
    PDFS = zeros(length(mWorkTest(:,1)),0);
    % for every found class creat gmm object model
    for index_i = 1:num_classes
        mGMM = zeros (0, length(mWorkTest(1,:)));
        % Crear matrix para GMM de training para esa clase
        for index_j = 1:length(mWorkTraining(:,1))
            if strcmp(cFeaturesTraining{20 + classType}{index_j}, Classes{index_i}) == 1
               mGMM = vertcat(mGMM, mWorkTraining(index_j,:));
            end
        end
        objGMM{index_i} = gmdistribution.fit (mGMM, 1);
        Y = pdf(objGMM{index_i}, mWorkTest);
        PDFS = horzcat(PDFS, Y);
    end
    % calculate fdp for every value of every column for every object GMM
    % and choose the one with greater fdp
    for index_i = 1:length(mWorkTest(:,1))
        prob = 0.0;
        pos = 0;
        
        for index_j = 1:num_classes
            if PDFS(index_i,index_j) > prob
                prob = PDFS(index_i,index_j);
                pos = index_j;
            end
        end
        if pos > 0
            results{1}{index_i} = Classes{pos};
            results{2}(index_i) = prob;
        else
            results{1}{index_i} = 'Desconegut';
            results{2}(index_i) = 0;
        end
    end
    
    output = results;
    
end

