function output = TFCKNNSearch( cFeaturesTraining, mTraining, mTest, scale, classType, k, maxDist )
%   File: TFCKNNSearch.m
%   Description: Perform GMM Classification
%   Input:
%       cFeaturesTraining - Cell Array with training features
%       mTraining - array with the features to check from training
%       mTest - array with features to classify from test
%       scale - 1 means to scale [-1,1]; 0 means not to scale
%       classType - Classes:
%                       0 - familia
%                       1 - subfamilia
%                       2 - instrument
%       k - numbers of neigbourgs
%       maxDist - maximum accepted distance
%   Output:
%       Cell Array with Label classification and value of fdp
%
%   Version: 1.0
%   Author: Juan Castro Mayorgas (jcastrom@uoc.edu)
%   (c) Copyright 2011 Juan Castro Mayorgas

    % Check classtype
    if classType < 0 || classType > 2
        error ('Tipus de Class erroni');
    end
    
    % Scale if needed
    if scale == 1
        [mWorkTraining mWorkTest] = TFCScaleMatrices (mTraining, mTest);
    elseif scale == 0
        mWorkTraining  = mTraining;
        mWorkTest = mTest;
    else
        error ('error en el parametre ''scale''');
    end
    
    % create result cell array columns
    results{1} = cell(length(mWorkTest(:,1)),1);
    results{2} = zeros(length(mWorkTest(:,1)),1);
    s = struct ('Label', {},'Repetitions', {}, 'Distance', {});
    
    cLabels = cFeaturesTraining{20 + classType};
    Label = '';
    
    [IDX DIST] = knnsearch (mWorkTraining, mWorkTest, 'k', k);

    for index_i = 1:length(mWorkTest(:,1))
        Label = cLabels{IDX(index_i)};
        Distance = DIST(index_i);
        if k > 1
            for index_j = 1:k
                s(index_j).Label = '';
                s(index_j).Repetitions = -1;
                s(index_j).Distance = 99;
            end
            for index_j = 1:k
                index_k = 1;
                Label = cLabels{IDX(index_i, index_j)};
                if maxDist == 0 || DIST(index_i, index_j) <= maxDist
                    while index_k <= k
                        if isempty(s(index_k).Label) 
                            s(index_k).Label = Label;
                            s(index_k).Repetitions = 1;
                            s(index_k).Distance = DIST(index_i,index_j);
                            break
                        end
                        if strcmp(s(index_k).Label, Label) == 1
                            s(index_k).Repetitions = s(index_k).Repetitions + 1;
                            s(index_k).Distance = s(index_k).Distance + DIST(index_i,index_j);
                            break
                        end
                        %% es diferente y por tanto buscar otra casilla libre
                        index_k = index_k + 1;
                    end
                end
            end
            Repetitions = 0;
            index_m = 1;
            Distance = -1;
            while index_m <= k && s(index_m).Repetitions ~= -1
                if s(index_m).Repetitions > Repetitions 
                    Repetitions = s(index_m).Repetitions;
                    Label = s(index_m).Label;
                    Distance = (s(index_m).Distance / Repetitions);
                elseif s(index_m).Repetitions == Repetitions
                    Label = 'Incert';
                end
                index_m = index_m + 1;
            end
        end
        if maxDist == 0 || Distance < maxDist
            results{1}{index_i} = Label;
            results{2}(index_i) = Distance;
        else
            results{1}{index_i} = 'Incert';            
            results{2}(index_i) = Distance;
        end
    end
    
    output = results;

end

