function output = TFCReportAnalytics( cAnalytics )
%   File: TFCReportAnalytics.m
%   Description: Summarize analytics cell array data
%
%   Input:
%       cFeaturesTraining, CfeaturesTest - cell array features
%       vWhat - 18 positions vector with 1 or 0. If 0, the feature is not
%               chosen.
%                                                   
%   Output:
%       cell array with instrument, test label, and searched label
%       
%   Version: 1.0
%   Author: Juan Castro Mayorgas (jcastrom@uoc.edu)
%   (c) Copyright 2011 Juan Castro Mayorgas
%
    
    Instruments = {};
    
    index_cell = 0;
    for index_i = 1:length(cAnalytics{1})
        index_j = 1;
        while index_j <= index_cell
            if strcmp(Instruments{index_j},cAnalytics{2}{index_i}) == 1
                break
            end
            index_j = index_j + 1;
        end
        if index_j > index_cell
            Instruments{index_cell + 1} = cAnalytics{2}{index_i};
            index_cell = index_cell + 1;
        end
    end
    
    num_instruments = length(Instruments);

    results{1} = cell(num_instruments+1,1);
    results{2} = zeros(num_instruments+1,1);
    results{3} = zeros(num_instruments+1,1);
    results{4} = zeros(num_instruments+1,1);

    
    EncertsTotal = 0;
    ErradesTotal = 0;
   
    for index_i = 1:num_instruments
        results{1}{index_i} = Instruments{index_i};
        EncertsInstrument = 0;
        ErradesInstrument = 0;
        for index_j = 1:length(cAnalytics{1})
            if strcmp(cAnalytics{2}{index_j}, Instruments{index_i}) == 1
                if strcmp(cAnalytics{3}{index_j}, cAnalytics{4}{index_j}) == 1
                    EncertsInstrument = EncertsInstrument + 1;
                else
                    ErradesInstrument = ErradesInstrument + 1;
                end
            end
        end

        results{2}(index_i) = EncertsInstrument;
        results{3}(index_i) = ErradesInstrument;
        results{4}(index_i) = EncertsInstrument + ErradesInstrument;
        EncertsTotal = EncertsTotal + EncertsInstrument;
        ErradesTotal = ErradesTotal + ErradesInstrument;
    end
    results{1}{num_instruments+1} = 'Acumulats';
    results{2}(num_instruments+1) = EncertsTotal;
    results{3}(num_instruments+1) = ErradesTotal;
    results{4}(num_instruments+1) = EncertsTotal + ErradesTotal;        
    output = results;

end

