function output = TFCSVMSearch ( cFeaturesTraining, mTraining, mTest, classType )
%   File: TFCSVMSearch.m
%   Description: Perform SVM Classification
%   Input:
%       cFeaturesTraining - Cell Array with training features
%       mTraining - array with the features to check from training
%       mTest - array with features to classify from test
%       classType - Classes:
%                       0 - familia
%                       1 - subfamilia
%                       2 - instrument
%   Output:
%       Cell Array with Label classification and value of fdp
%
%   Version: 1.0
%   Author: Juan Castro Mayorgas (jcastrom@uoc.edu)
%   (c) Copyright 2011 Juan Castro Mayorgas

    % Comprovar classType
    
    if classType < 0 || classType > 2
        error ('classtype erroni');
    end
    
    % create results cell array columns
    results{1} = cell(length(mTest(:,1)),1);
    results{2} = zeros(length(mTest(:,1)),1);
    
    Classes = {};
    LABELS = cFeaturesTraining{20 + classType};
    
    % search for classes
    index_cell = 0;
    for index_i = 1:length(LABELS)
        index_j = 1;
        while index_j <= index_cell
            if strcmp(Classes{index_j},LABELS{index_i}) == 1
                break
            end
            index_j = index_j + 1;
        end
        if index_j > index_cell
            Classes{index_cell + 1} = LABELS{index_i};
            index_cell = index_cell + 1;
        end
    end
    
    num_classes = length(Classes);

    %% create SVMTRAIN.TXT
    fid = fopen('svmtrain.txt', 'w');
    for index_i = 1:length(mTraining(:,1))
        % Find class index 
        for index_cell = 1:num_classes
            if strcmp(Classes{index_cell}, cFeaturesTraining{20 + classType}{index_i}) == 1
                break
            end
        end
        fprintf(fid, '%d', index_cell);
        for index_j = 1:length(mTraining(1,:))
            fprintf(fid, ' %d:%f', index_j, mTraining(index_i, index_j));
        end
        fprintf(fid, '\n');
    end
    fclose(fid);

    %% Crear SVMTEST.TXT
    fid = fopen('svmTest.txt', 'w');
    for index_i = 1:length(mTest(:,1))
        % assing class index
        % don't need to do that, svn will guess it
%        for index_cell = 1:num_classes
%            if strcmp(Classes{index_cell}, cFeaturesTest{20 + classType}{index_i}) == 1
%                break
%            end
%        end
%        fprintf(fid, '%d', index_cell);
%       print 0 as label
        fprintf(fid, '0');
        for index_j = 1:length(mTest(1,:))
            fprintf(fid, ' %d:%f', index_j, mTest(index_i, index_j));
        end
        fprintf(fid, '\n');
    end
    fclose(fid);
    
    %% SCALE SVMTRAIN
    system('svm-scale -s range svmtrain.txt > svmtrain.scale');
    %% SCALE SVmTest
    system('svm-scale -r range svmTest.txt > svmTest.scale');
%%    system('svm-train -h 0 svmtrain.scale svmtrain.model');
    system('svm-train -q svmtrain.scale svmtrain.model');
    system('svm-predict svmTest.scale svmtrain.model svmresults.txt');
   
    %% Read results
    
    fid = fopen('svmresults.txt');
    Indexes = textscan(fid,'%d')
    fclose(fid);
    
    for index_i = 1:length(mTest(:,1))
        results{1}{index_i} = Classes{Indexes{1}(index_i)};
    end
    
    output = results;

    
    
end
    