function [mScaledA mScaledB] = TFCScaleMatrices(mA, mB)
%   File: TFCScaleMatrices.m
%   Description: Scale linearly in range [-1, 1] matrices mA and mB
%
%   newX = (OldX - lowerLimit) / (upperLimit - LowerLimit) * 2 - 1 
%
%   Input:
%       mA, mB - matrices to scale
%                                                   
%   Output:
%       mScaledA, mScaleB - scaled matrices
%       
%   Version: 1.0
%   Author: Juan Castro Mayorgas (jcastrom@uoc.edu)
%   (c) Copyright 2011 Juan Castro Mayorgas
%

    mScaledA = mA;
    mScaledB = mB;
    
    if length(mA(1,:)) ~= length(mB(1,:))
        error ('Les matrius han de tindre el mateix nombre de columnes');
    end
    
    % Calculate lower limit
    lLimit = min(min(mA), min(mB));
    % Calculate upper limit
    uLimit = max(max(mA), max(mB));
    
    
    % Scale every value of mScaledA
    for iCol = 1:length(mScaledA(1,:))
        for iRow = 1:length(mScaledA(:,1))
            mScaledA(iRow,iCol) = (mScaledA(iRow,iCol) - lLimit(iCol)) / (uLimit(iCol) - lLimit(iCol)) * 2 - 1;
        end
    end
    
    % Scale every value of mScaledB
    for iCol = 1:length(mScaledB(1,:))
        for iRow = 1:length(mScaledB(:,1))
            mScaledB(iRow,iCol) = (mScaledB(iRow,iCol) - lLimit(iCol)) / (uLimit(iCol) - lLimit(iCol)) * 2 - 1;
        end
    end
    
end

